@@ -515,7 +515,7 @@ class QuoteData(object):
         return df
 
     @assert_quote_init
-    def get_quote_date(self) -> time.struct_time:
+    def get_quote_date(self) -> datetime.date:
         """获取行情日期
 
         返回值:
@@ -544,11 +544,11 @@ class QuoteData(object):
         stime = result.get('last_date')
         if not stime:
             raise Exception('the quote_data not found.')
-        last_date = time.strptime(stime, '%Y-%m-%d')
+        last_date = datetime.datetime.strptime(stime, '%Y-%m-%d').date()
         tdays = self.get_trade_days(end_date=last_date, count=1)
         if not tdays:
             raise Exception('trade-days is empty.')
-        return formatter_st(tdays[0])
+        return tdays[0]
 
     @assert_quote_init
     def get_trade_days(self, start_date=None, end_date=None, count=None) -> list:
