@@ -3,8 +3,8 @@
 import threading
 from functools import wraps
 
-import numpy
-import pandas
+import numpy as np
+import pandas as pd
 
 
 class ArithmeticQuoteValue(object):
@@ -149,7 +149,7 @@ class ArithmeticContainer(object):
 
 class ArithmeticOperator(object):
     def __init__(self):
-        self._data = pandas.DataFrame()
+        self._data = pd.DataFrame()
         self._stats = []
         self._index = 0
 
@@ -236,19 +236,19 @@ class ArithmeticStatistics(object):
     def std(self, x, n):
         x = self._val(x)
         self._update(x, n)
-        self._result = float(numpy.std(self._data[-n:]))
+        self._result = float(np.std(self._data[-n:]))
         return self._result
 
     def sum(self, x, n=0):
         x = self._val(x)
         self._update(x, n)
-        self._result = float(numpy.sum(self._data[-n:]))
+        self._result = float(np.sum(self._data[-n:]))
         return self._result
 
     def ma(self, x, n):
         x = self._val(x)
         self._update(x, n)
-        self._result = float(numpy.mean(self._data[-n:])) if len(self._data) >= n else None
+        self._result = float(np.mean(self._data[-n:])) if len(self._data) >= n else None
         return self._result
 
     def ema(self, x, n):
@@ -267,20 +267,20 @@ class ArithmeticStatistics(object):
     def hhv(self, x, n):
         x = self._val(x)
         self._update(x, n)
-        self._result = float(numpy.max(self._data[-n:]))
+        self._result = float(np.max(self._data[-n:]))
         return self._result
 
     def llv(self, x, n):
         x = self._val(x)
         self._update(x, n)
-        self._result = float(numpy.min(self._data[-n:]))
+        self._result = float(np.min(self._data[-n:]))
         return self._result
 
 
 def arithmetic_wrapper(func):
     @wraps(func)
     def _wrapper(*args, **kwargs):
-        if args and type(args[0]) is pandas.Series:
+        if args and type(args[0]) is pd.Series:
             data = args[0]
             arith = ArithmeticContainer()
             arith.reset(data['code'])
@@ -295,9 +295,9 @@ def arithmetic_wrapper(func):
             except (TypeError, ZeroDivisionError):
                 returns = arithmetic_returns(func.__code__)
                 if type(returns) is list:
-                    arith.result = (0 for i in range(len(returns)))
+                    arith.result = tuple([np.nan for i in range(len(returns))])
                 else:
-                    arith.result = 0
+                    arith.result = np.nan
             return arith.result
         else:
             return func(*args, **kwargs)
